# Generated by Django 2.2.6 on 2019-12-04 00:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simple_django_teams', '0001_initial'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='team',
            name='unique_active_organisation_names',
        ),
        migrations.AddConstraint(
            model_name='team',
            constraint=models.UniqueConstraint(condition=models.Q(deletion_time__isnull=True), fields=('name',), name='unique_active_team_names'),
        ),
    ]
